use strict;
use warnings;

package Apache2::CaptivePortal;

=head1 NAME

Apache2::CaptivePortal - Sets up a simple, informational-only captive portal

=head1 SYNOPSIS


=head1 REQUIRES

- Apache 2.0
- Perl 5.8
- Mod_perl 2.0
- Net::ARP
- Template Toolkit

=head1 SEE ALSO

=head1 AUTHOR

Gunnar Wolf <gwolf@gwolf.org>

=head1 COPYRIGHT

Copyright 2006 Gunnar Wolf / Instituto de Investigaciones Econmicas UNAM
This module is Free Software, it can be redistributed under the same terms
as Perl.

=cut

use Apache::Const qw(:common);
use Net::ARP;
use Template;

sub handler {
    my ($r, $conn, $iface, $tmpldir, $lang, $extra, $html, $tt, $ip, $mac);
    $r = shift;
    $conn = $r->connection;

    $iface = $r->dir_config('iface') || 'eth0';
    $tmpldir = $r->dir_config('tmpldir');
    $lang = 'lang/' . $r->dir_config('lang');
    $extra = $r->dir_config('extra_data');

    # Initialize Template Toolkit with the specified language file
    # If no language file is specified or it does not exist, the system will
    # be kind-of-usable anyway... But we should at least send a warning.
    unless (-f "$tmpldir/$lang") {
	warn "Requested language file ($tmpldir/$lang) was not found\n";
	warn "Entering IPmanage with no language. This will not be pretty.\n";

	# Keep Template from panicing
	undef $lang;
    }
    $tt = Template->new(INCLUDE_PATH => $tmpldir,
			PRE_PROCESS => $lang,
			OUTPUT => \$html) or die Template->error;

    $mac = '';
    $ip = $conn->remote_ip;
    Net::ARP::arp_lookup($iface, $ip, $mac);

    $tt->process('captive_portal.tmpl', {ip => $ip,
					 mac => $mac,
					 extra_data => $extra})
	or die $tt->error;

    $r->no_cache(1);
    $r->content_type('text/html');
    print($html);

    return OK;
}

1;
